@@ -1,9 +1,10 @@
 #ifndef RXVT_DAEMON_H
 #define RXVT_DAEMON_H
 
-#include "rxvtstl.h"
+#include "rxvtutil.h"
 
-struct rxvt_connection {
+struct rxvt_connection
+{
   int fd;
 
   static char *unix_sockname ();
