@@ -13,18 +13,23 @@ using namespace std;
 
 #define HAVE_GCC_BUILTINS (__GNUC__ >= 4 || (__GNUC__ == 3 && __GNUC_MINOR__ == 4))
 
-#ifndef __attribute__
-# if __GNUC__
-#  if (__GNUC__ == 2 && __GNUC_MINOR__ < 5) || (__GNUC__ < 2)
-#   define __attribute__(x)
-#  endif
-# endif
-# define __attribute__(x)
+#if __GNUC__ >= 4
+# define rxvt_attribute(x) __attribute__(x)
+# define expect(expr,value)         __builtin_expect ((expr),(value))
+#else
+# define rxvt_attribute(x)
+# define expect(expr,value)         (expr)
 #endif
 
-#define NORETURN __attribute__ ((noreturn))
-#define UNUSED   __attribute__ ((unused))
-#define CONST    __attribute__ ((const))
+// put into ifs if you are very sure that the expression
+// is mostly true or mosty false. note that these return
+// booleans, not the expression.
+#define expect_false(expr) expect ((expr) != 0, 0)
+#define expect_true(expr)  expect ((expr) != 0, 1)
+
+#define NORETURN rxvt_attribute ((noreturn))
+#define UNUSED   rxvt_attribute ((unused))
+#define CONST    rxvt_attribute ((const))
 
 // increases code size unless -fno-enforce-eh-specs
 #if __GNUC__
@@ -67,14 +72,34 @@ T lerp (T a, U b, P p)
   return (long(a) * long(100 - p) + long(b) * long(p) + 50) / 100;
 }
 
+template <typename I, typename T>
+I find (I first, I last, const T& value)
+{
+  while (first != last && *first != value)
+    ++first;
+
+  return first;
+}
+
+// return a very temporary (and never deallocated) buffer. keep small.
+void *rxvt_temp_buf (int len);
+
+template<typename T>
+static inline T *
+rxvt_temp_buf (int len)
+{
+  return (T *)rxvt_temp_buf (len * sizeof (T));
+}
+
 // some bit functions, xft fuck me plenty
 #if HAVE_GCC_BUILTINS
-static inline int ctz      (unsigned int x) CONST { return __builtin_ctz      (x); }
-static inline int popcount (unsigned int x) CONST { return __builtin_popcount (x); }
+/* netbsd stupidly defines popcount itself and puts it into string.h */
+static inline int rxvt_ctz      (unsigned int x) { return __builtin_ctz      (x); }
+static inline int rxvt_popcount (unsigned int x) { return __builtin_popcount (x); }
 #else
 // count trailing zero bits and count # of one bits
-int ctz      (unsigned int x) CONST;
-int popcount (unsigned int x) CONST;
+int rxvt_ctz      (unsigned int x) CONST;
+int rxvt_popcount (unsigned int x) CONST;
 #endif
 
 // in range including end
@@ -85,19 +110,24 @@ int popcount (unsigned int x) CONST;
 #define IN_RANGE_EXC(val,beg,end) \
   ((unsigned int)(val) - (unsigned int)(beg) <  (unsigned int)(end) - (unsigned int)(beg))
 
+// for m >= -n, ensure remainder lies between 0..n-1
+#define MOD(m,n) (((m) + (n)) % (n))
+
 // makes dynamically allocated objects zero-initialised
-struct zero_initialized {
+struct zero_initialized
+{
   void *operator new (size_t s);
   void operator delete (void *p, size_t s);
 };
 
 /* simplevec taken (and heavily modified), from:
- * 
+ *
  *  MICO --- a free CORBA implementation
  *  Copyright (C) 1997-98 Kay Roemer & Arno Puder
  */
 template<class T>
-struct simplevec {
+struct simplevec
+{
     typedef T* iterator;
     typedef const T* const_iterator;
     typedef unsigned long size_type;
@@ -348,11 +378,22 @@ bool operator< (const simplevec<T> &v1, const simplevec<T> &v2)
 
 template<typename T>
 struct vector : simplevec<T>
-{ };
+{
+};
+
+struct stringvec : simplevec<char *>
+{
+  ~stringvec ()
+  {
+    for (char **c = begin (); c != end (); c++)
+      free (*c);
+  }
+};
 
 #if 0
 template<typename T>
-struct rxvt_vec : simplevec<void *> {
+struct rxvt_vec : simplevec<void *>
+{
   typedef T *iterator;
 
   void push_back (T d) { simplevec<void *>::push_back ((void *)d); }
@@ -366,17 +407,9 @@ struct rxvt_vec : simplevec<void *> {
 };
 #endif
 
-template <typename I, typename T>
-I find (I first, I last, const T& value)
-{
-  while (first != last && *first != value)
-    ++first;
-
-  return first;
-}
-
 template<typename T>
-struct auto_ptr {
+struct auto_ptr
+{
   T *p;
 
   auto_ptr () : p (0) { }
@@ -435,24 +468,5 @@ struct auto_ptr {
 
 typedef auto_ptr<char> auto_str;
 
-struct stringvec : simplevec<char *>
-{
-  ~stringvec ()
-  {
-    for (char **c = begin (); c != end (); c++)
-      free (*c);
-  }
-};
-
-// return a very temporary (and never deallocated) buffer. keep small.
-void *rxvt_temp_buf (int len);
-
-template<typename T>
-static inline T *
-rxvt_temp_buf (int len)
-{
-  return (T *)rxvt_temp_buf (len * sizeof (T));
-}
-
 #endif
 
