@@ -110,7 +110,7 @@ will be called when the toggle changes, with the new boolean value as
 first argument.
 
 The following will add an entry C<myoption> that changes
-C<$self->{myoption}>:
+C<< $self->{myoption} >>:
 
    push @{ $self->{term}{option_popup_hook} }, sub {
       ("my option" => $myoption, sub { $self->{myoption} = $_[0] })
@@ -305,6 +305,12 @@ extension will actually grab a physical key just for this function.
 If you want a quake-like animation, tell your window manager to do so
 (fvwm can do it).
 
+=item overlay-osc
+
+This extension implements some OSC commands to display timed popups on the
+screen - useful for status displays from within scripts. You have to read
+the sources for more info.
+
 =item block-graphics-to-ascii
 
 A not very useful example of filtering all text output to the terminal
@@ -369,6 +375,20 @@ the double C</> characters as comment start. Use C<\057\057> instead,
 which works regardless of wether xrdb is used to parse the resource file
 or not.
 
+=item macosx-pastebin and macosx-pastebin-native
+
+These two modules implement an extended clipboard for Mac OS X. They are
+used like this:
+
+   URxvt.perl-ext-common: default,macosx-clipboard
+   URxvt.keysym.M-c: perl:macosx-clipboard:copy
+   URxvt.keysym.M-v: perl:macosx-clipboard:paste
+
+The difference between them is that the native variant requires a
+perl from apple's devkit or so, and C<maxosx-pastebin> requires the
+C<Mac::Pasteboard> module, works with other perls, has fewer bugs, is
+simpler etc. etc.
+
 =item example-refresh-hooks
 
 Displays a very simple digital clock in the upper right corner of the
@@ -543,29 +563,42 @@ It is called before lines are scrolled out (so rows 0 .. min ($lines - 1,
 $nrow - 1) represent the lines to be scrolled out). C<$saved> is the total
 number of lines that will be in the scrollback buffer.
 
-=item on_osc_seq $term, $op, $args
+=item on_osc_seq $term, $op, $args, $resp
 
 Called on every OSC sequence and can be used to suppress it or modify its
-behaviour.  The default should be to return an empty list. A true value
+behaviour. The default should be to return an empty list. A true value
 suppresses execution of the request completely. Make sure you don't get
-confused by recursive invocations when you output an osc sequence within
+confused by recursive invocations when you output an OSC sequence within
 this callback.
 
 C<on_osc_seq_perl> should be used for new behaviour.
 
-=item on_osc_seq_perl $term, $string
+=item on_osc_seq_perl $term, $args, $resp
 
 Called whenever the B<ESC ] 777 ; string ST> command sequence (OSC =
 operating system command) is processed. Cursor position and other state
 information is up-to-date when this happens. For interoperability, the
-string should start with the extension name and a colon, to distinguish
-it from commands for other extensions, and this might be enforced in the
-future.
+string should start with the extension name (sans -osc) and a semicolon,
+to distinguish it from commands for other extensions, and this might be
+enforced in the future.
+
+For example, C<overlay-osc> uses this:
+
+   sub on_osc_seq_perl {
+      my ($self, $osc, $resp) = @_;
+
+      return unless $osc =~ s/^overlay;//;
+
+      ... process remaining $osc string
+   }
 
 Be careful not ever to trust (in a security sense) the data you receive,
 as its source can not easily be controlled (e-mail content, messages from
 other users on the same system etc.).
 
+For responses, C<$resp> contains the end-of-args separator used by the
+sender.
+
 =item on_add_lines $term, $string
 
 Called whenever text is about to be output, with the text as argument. You
@@ -595,8 +628,8 @@ you cannot just toggle rendition bits, but only set them.
 
 =item on_refresh_begin $term
 
-Called just before the screen gets redrawn. Can be used for overlay
-or similar effects by modify terminal contents in refresh_begin, and
+Called just before the screen gets redrawn. Can be used for overlay or
+similar effects by modifying the terminal contents in refresh_begin, and
 restoring them in refresh_end. The built-in overlay and selection display
 code is run after this hook, and takes precedence.
 
@@ -1093,7 +1126,7 @@ work.
 
 =cut
 
-our $VERSION = '3.4';
+our $VERSION = '5.23';
 
 $INC{"urxvt/anyevent.pm"} = 1; # mark us as there
 push @AnyEvent::REGISTRY, [urxvt => urxvt::anyevent::];
@@ -1105,8 +1138,8 @@ sub timer {
 
    urxvt::timer
       ->new
-      ->start (urxvt::NOW + $arg{after})
-      ->cb (sub {
+      ->after ($arg{after}, $arg{interval})
+      ->cb ($arg{interval} ? $cb : sub {
         $_[0]->stop; # need to cancel manually
         $cb->();
       })
@@ -1116,18 +1149,42 @@ sub io {
    my ($class, %arg) = @_;
 
    my $cb = $arg{cb};
+   my $fd = fileno $arg{fh};
+   defined $fd or $fd = $arg{fh};
 
    bless [$arg{fh}, urxvt::iow
              ->new
-             ->fd (fileno $arg{fh})
+             ->fd ($fd)
              ->events (($arg{poll} =~ /r/ ? 1 : 0)
                      | ($arg{poll} =~ /w/ ? 2 : 0))
              ->start
-             ->cb (sub {
-                $cb->(($_[1] & 1 ? 'r' : '')
-                    . ($_[1] & 2 ? 'w' : ''));
-             })],
-         urxvt::anyevent::
+             ->cb ($cb)
+         ], urxvt::anyevent::
+}
+
+sub idle {
+   my ($class, %arg) = @_;
+
+   my $cb = $arg{cb};
+
+   urxvt::iw
+      ->new
+      ->start
+      ->cb ($cb)
+}
+
+sub child {
+   my ($class, %arg) = @_;
+
+   my $cb = $arg{cb};
+
+   urxvt::pw
+      ->new
+      ->start ($arg{pid})
+      ->cb (sub {
+        $_[0]->stop; # need to cancel manually
+        $cb->($_[0]->rpid, $_[0]->rstatus);
+      })
 }
 
 sub DESTROY {
@@ -1267,9 +1324,9 @@ to see the actual list:
   borderLess chdir color cursorBlink cursorUnderline cutchars delete_key
   display_name embed ext_bwidth fade font geometry hold iconName
   imFont imLocale inputMethod insecure int_bwidth intensityStyles
-  italicFont jumpScroll lineSpace loginShell mapAlert meta8 modifier
-  mouseWheelScrollPage name override_redirect pastableTabs path perl_eval
-  perl_ext_1 perl_ext_2 perl_lib pointerBlank pointerBlankDelay
+  italicFont jumpScroll lineSpace letterSpace loginShell mapAlert meta8
+  modifier mouseWheelScrollPage name override_redirect pastableTabs path
+  perl_eval perl_ext_1 perl_ext_2 perl_lib pointerBlank pointerBlankDelay
   preeditType print_pipe pty_fd reverseVideo saveLines scrollBar
   scrollBar_align scrollBar_floating scrollBar_right scrollBar_thickness
   scrollTtyKeypress scrollTtyOutput scrollWithBuffer scrollstyle
@@ -1317,8 +1374,15 @@ set it (which is usually bad as applications don't expect that).
 
 =item ($row, $col) = $term->selection_end ([$row, $col])
 
-Return the current values of the selection mark, begin or end positions,
-and optionally set them to new values.
+Return the current values of the selection mark, begin or end positions.
+
+When arguments are given, then the selection coordinates are set to
+C<$row> and C<$col>, and the selection screen is set to the current
+screen.
+
+=item $screen = $term->selection_screen ([$screen])
+
+Returns the current selection screen, and then optionally sets it.
 
 =item $term->selection_make ($eventtime[, $rectangular])
 
@@ -1375,12 +1439,14 @@ The methods currently supported on C<urxvt::overlay> objects are:
 
 =over 4
 
-=item $overlay->set ($x, $y, $text, $rend)
+=item $overlay->set ($x, $y, $text[, $rend])
 
 Similar to C<< $term->ROW_t >> and C<< $term->ROW_r >> in that it puts
 text in rxvt-unicode's special encoding and an array of rendition values
 at a specific position inside the overlay.
 
+If C<$rend> is missing, then the rendition will not be changed.
+
 =item $overlay->hide
 
 If visible, hide the overlay, but do not destroy it.
@@ -1996,17 +2062,14 @@ immediately.
 
 Set the callback to be called when the timer triggers.
 
-=item $tstamp = $timer->at
+=item $timer = $timer->set ($tstamp[, $interval])
 
-Return the time this watcher will fire next.
-
-=item $timer = $timer->set ($tstamp)
-
-Set the time the event is generated to $tstamp.
+Set the time the event is generated to $tstamp (and optionally specifies a
+new $interval).
 
 =item $timer = $timer->interval ($interval)
 
-Normally (and when C<$interval> is C<0>), the timer will automatically
+By default (and when C<$interval> is C<0>), the timer will automatically
 stop after it has fired once. If C<$interval> is non-zero, then the timer
 is automatically rescheduled at the given intervals.
 
@@ -2014,11 +2077,12 @@ is automatically rescheduled at the given intervals.
 
 Start the timer.
 
-=item $timer = $timer->start ($tstamp)
+=item $timer = $timer->start ($tstamp[, $interval])
 
-Set the event trigger time to C<$tstamp> and start the timer.
+Set the event trigger time to C<$tstamp> and start the timer. Optionally
+also replaces the interval.
 
-=item $timer = $timer->after ($delay)
+=item $timer = $timer->after ($delay[, $interval])
 
 Like C<start>, but sets the expiry timer to c<urxvt::NOW + $delay>.
 
